KEYWORDS = {
    "!": "run",
    "?": "help",
    "--help": "help",
    "H": "hardware",
    "I": "install",
    "K": "Kanata",
    "P": "plugins",
    "T": "terraform",
    "V": "verbose",
    "abcli": "awesome-bash-cli",
    "am": "add_month",
    "at": "add_to",
    "bp": "blue_plugin",
    "bsbc": "blue_sbc",
    "bld": "build",
    "br": "browser",
    "bs": "blue-stability",
    "bw": "blue-wiki",
    "bwiki": "blue-wiki",
    "cp": "copy",
    "det": "detect",
    "dl": "download",
    "ds": "dataset",
    "em": "earthdaily_mosaic",
    "eval": "evaluate",
    "fm": "fashion_mnist",
    "gmp": "get_model_path",
    "hf": "huggingface",
    "ic": "image_classifier",
    "id": "identify",
    "ing": "ingest",
    "iranwatch": "iran-watching",
    "Kw": "Kanata_web",
    "le": "list_of_external",
    "ls": "list",
    "mcsai": "mayo_clinic_strip_ai",
    "nbs": "notebooks-and-scripts",
    "obj": "object",
    "op": "open",
    "pk": "pack_keyword",
    "pr": "predict",
    "pub": "publish",
    "roof": "roofAI",
    "rndr": "render",
    "rv22": "RAW_Vancouver_PORTAL_2022",
    "sel": "select",
    "sl": "solid",
    "tf": "training_framework",
    "tr": "train",
    "uf": "update_fork",
    "uk": "unpack_keyword",
    "ul": "upload",
    "up": "upload",
    "upd": "update",
    "val": "validate",
    "vanwatch": "vancouver-watching",
    "yolo": "yolov5",
    "yt": "youtube",
}
